# smemhack_win10_pro
**smemhack_win10_pro** A special version of smemhack just for win 10 pro user

# What is inside:

1.having a compare system to finish smem

**What is new in version 1.0**

Nothing special,go to https://pypi.org/project/smemhack/ check out normal version

# What is new in version 1.1

Now it will auto upgrade the program so you no need to upgrade yourself

**How to Use it:**

copy the code i give in the last of this discription and change the new_word_number to the number of new word you have entered

1.Prepare a started solidmemory page(exercise page)

2.Run the code
## Usage
To use the library, simply call the `hack()` function:
```python
from smemhack_win10_pro import hack

hack(new_word_number)
